@@ -32,7 +32,7 @@ package Apache2::AMFWURFLFilter;
   # 
 
   use vars qw($VERSION);
-  $VERSION= "3.33";
+  $VERSION= "3.40a";
   my $CommonLib = new Apache2::AMFCommonLib ();
  
   my %Capability;
@@ -63,6 +63,7 @@ package Apache2::AMFWURFLFilter;
   my $capabilitylist="none";
   my $restmode='false';
   my $deepSearch=0;
+  my $checkVersion='false';
 
   $CommonLib->printLog("---------------------------------------------------------------------------"); 
   $CommonLib->printLog("-------                 APACHE MOBILE FILTER V$VERSION                  -------");
@@ -72,8 +73,30 @@ package Apache2::AMFWURFLFilter;
   $CommonLib->printLog("--- The WURFL file is the Copyright of ScientiaMobile, read the license ---");
   $CommonLib->printLog("--- For more info: http://www.scientiamobile.com.                       ---");
   $CommonLib->printLog("---------------------------------------------------------------------------");
-
   $CommonLib->printLog("AMFWURFLFilter module Version $VERSION");
+  if ($ENV{AMFCheckVersion}) {
+	$checkVersion=$ENV{AMFCheckVersion};
+  }
+  if ($checkVersion eq 'true') {
+	$CommonLib->printLog("Check on apchemobilefilter.org if the installed AMF is the last version");  
+        $CommonLib->printLog("Try to download http://www.apachemobilefilter.org/param/amf.config");
+	my $url="http://www.apachemobilefilter.org/param/amf.config";
+	my $content = get ($url);
+	$content =~ s/\n//g;
+	my $check_version=0;
+	if ($content) {
+	  $check_version=$content;
+	}
+	if ($check_version > $VERSION && $check_version ne 0) {
+	       $CommonLib->printLog("---------------------------------------------------------------------------");
+	       $CommonLib->printLog("-----           There is a new version of AMF V$check_version online             ----");
+	       $CommonLib->printLog("---------------------------------------------------------------------------");
+	} else {
+		$CommonLib->printLog("AMF installed is the last version");
+	}
+  } else {
+	$CommonLib->printLog("AMFCheckVersione is false, AMF don't check the last version.");
+  }
   if ($ENV{ResizeImageDirectory}) {
 	  $Capability{'max_image_width'}="max_image_width";
 	  $Capability{'max_image_height'}="max_image_width"; 
@@ -204,9 +227,9 @@ sub loadConfigFile {
 		}
 		if ($ENV{AMFDeepParse}) {
 			$deepSearch=$ENV{AMFDeepParse};
-			$CommonLib->printLog("RestMode is: $deepSearch");			
+			$CommonLib->printLog("AMFDeepParse is: $deepSearch");			
 		} else {
-				$CommonLib->printLog("AMFDeepParse  is not setted the default value is 3");			   
+				$CommonLib->printLog("AMFDeepParse  is not setted the default value is 0");			   
 		}
 
 	    $CommonLib->printLog("Finish loading  parameter");
@@ -587,7 +610,7 @@ sub IdentifyPCUAMethod {
   my $pair;
   my $length=0;
 
-  foreach $pair (sort %PCArray) {
+  foreach $pair (sort keys %PCArray) {
 	if ($UserAgent =~ m/$pair/) {
 		$id_find=$PCArray{$pair};
 	}
@@ -624,12 +647,15 @@ sub handler {
     my $width_toSearch;
     my $type_redirect="internal";
     my $return_value;
-	my $dummy="";
-	my $variabile2="";
-	my %ArrayCapFound;
-	my $controlCookie;
-	my $query_img="";
-	$ArrayCapFound{is_transcoder}='false';
+    my $dummy="";
+    my $variabile2="";
+    my %ArrayCapFound;
+    my $controlCookie;
+    my $query_img="";
+    $ArrayCapFound{is_transcoder}='false';
+    $ArrayCapFound{'device_claims_web_support'}='none';
+    $ArrayCapFound{'is_wireless_device'}='none';
+
     my %ArrayQuery;
     my $var;
     my $mobile=0;
@@ -710,9 +736,7 @@ sub handler {
 							}
 						}
 						if ($mobile==0) {
-							$f->log->warn("$user_agent");
 							$user_agent=$CommonLib->botDetection($user_agent);    
-							$f->log->warn("$user_agent");
 							$id=IdentifyPCUAMethod($user_agent);
 						} 
 					}
@@ -724,16 +748,18 @@ sub handler {
 							$id='generic_web_browser';
 					} else {
 						#this check the correct version of Android
-						if ($version ne 'nc') {
-							my $lengthId=length($version);
-							my $count=0;
-							while($count<$lengthId) {								
-								my $idToCheck=$id."_sub".substr($version,0,length($version)-$count);
-								if ($Array_fb{$idToCheck}) {
-									$id=$idToCheck;
-									$count=$lengthId;
+						if ($version) {
+							if ($version ne 'nc') {
+								my $lengthId=length($version);
+								my $count=0;
+								while($count<$lengthId) {								
+									my $idToCheck=$id."_sub".substr($version,0,length($version)-$count);
+									if ($Array_fb{$idToCheck}) {
+										$id=$idToCheck;
+										$count=$lengthId;
+									}
+									$count++;
 								}
-								$count++;
 							}
 						}
 					}
@@ -777,7 +803,15 @@ sub handler {
 				$f->err_headers_out->set('Set-Cookie' => "amf=$id; path=/;");	
 			}		  			  
 	      	} 
-    }		
+    }
+        my $amf_device_ismobile = 'true';
+	if (($ArrayCapFound{'device_claims_web_support'}) && ($ArrayCapFound{'device_claims_web_support'})) {
+		if ($ArrayCapFound{'device_claims_web_support'} eq 'true' && $ArrayCapFound{'is_wireless_device'} eq 'false') {
+			$amf_device_ismobile = 'false';		
+		}
+	}
+	$f->pnotes("amf_device_ismobile" => $amf_device_ismobile); 
+	$f->subprocess_env("AMF_DEVICE_IS_MOBILE" => $amf_device_ismobile);
 	$f->subprocess_env("AMF_VER" => $VERSION);
 	$f->subprocess_env("AMF_WURFLVER" => $WURFLVersion);
 	$f->subprocess_env("AMF_PATCHFILEVER" => $WURFLPatchVersion);
