@@ -33,7 +33,7 @@ package Apache2::AMFWURFLFilterMemcached;
 
   use vars qw($VERSION);
   my $CommonLib = new Apache2::AMFCommonLib ();
-  $VERSION= "3.33";
+  $VERSION= "3.40a";
   my %Capability;
   my %Array_fb;
   my %Array_id;
@@ -61,6 +61,7 @@ package Apache2::AMFWURFLFilterMemcached;
   my $serverMemCache;
   my $restmode='false';
   my $deepSearch=0;
+  my $checkVersion='false';
   
   $CommonLib->printLog("---------------------------------------------------------------------------"); 
   $CommonLib->printLog("-------                 APACHE MOBILE FILTER V$VERSION                  -------");
@@ -70,8 +71,30 @@ package Apache2::AMFWURFLFilterMemcached;
   $CommonLib->printLog("--- The WURFL file is the Copyright of ScientiaMobile, read the license ---");
   $CommonLib->printLog("--- For more info: http://www.scientiamobile.com.                       ---");
   $CommonLib->printLog("---------------------------------------------------------------------------");
-
   $CommonLib->printLog("AMFWURFLFilterMemcached module Version $VERSION");
+  if ($ENV{AMFCheckVersion}) {
+	$checkVersion=$ENV{AMFCheckVersion};
+  }
+  if ($checkVersion eq 'true') {
+	$CommonLib->printLog("Check on apchemobilefilter.org if the installed AMF is the last version");
+        $CommonLib->printLog("Try to download http://www.apachemobilefilter.org/param/amf.config");
+	my $url="http://www.apachemobilefilter.org/param/amf.config";
+	my $content = get ($url);
+	$content =~ s/\n//g;
+	my $check_version=0;
+	if ($content) {
+	  $check_version=$content;
+	}
+	if ($check_version > $VERSION && $check_version ne 0) {
+	       $CommonLib->printLog("---------------------------------------------------------------------------");
+	       $CommonLib->printLog("-----           There is a new version of AMF V$check_version online             ----");
+	       $CommonLib->printLog("---------------------------------------------------------------------------");
+	} else {
+		$CommonLib->printLog("AMF installed is the last version");
+	}
+  } else {
+	$CommonLib->printLog("AMFCheckVersione is false, AMF don't check the last version.");
+  }
   if ($ENV{ResizeImageDirectory}) {
 	  $Capability{'max_image_width'}="max_image_width";
 	  $Capability{'max_image_height'}="max_image_width"; 
@@ -207,9 +230,9 @@ sub loadConfigFile {
 		}
 		if ($ENV{AMFDeepParse}) {
 			$deepSearch=$ENV{AMFDeepParse};
-			$CommonLib->printLog("RestMode is: $deepSearch");			
+			$CommonLib->printLog("AMFDeepParse is: $deepSearch");			
 		} else {
-				$CommonLib->printLog("AMFDeepParse  is not setted the default value is 3");			   
+				$CommonLib->printLog("AMFDeepParse  is not setted the default value is 0");			   
 		}
 	    $CommonLib->printLog("Finish loading  parameter");
 		$CommonLib->printLog("---------------------------------------------------------------------------"); 
@@ -439,7 +462,7 @@ sub IdentifyPCUAMethod {
   my $id_find="";
   my $pair;
   my $length=0;
-  foreach $pair (sort %PCArray) {
+  foreach $pair (sort keys %PCArray) {
 	if ($UserAgent =~ m/$pair/) {
 		$id_find=$PCArray{$pair};
 	}
@@ -505,7 +528,7 @@ sub parseWURFLFile {
 	           $id=substr($record,index($record,'id') + 4,index($record,'"',index($record,'id')+ 5)- index($record,'id') - 4);
 	        }	        
 	        if (index($record,'fall_back') > 0 ) {
-	           $fb=substr($record,index($record,'fall_back') + 11,index($record,'"',index($record,'fall_back')+ 12)- index($record,'fall_back') - 11);	           
+	           $fb=substr($record,index($record,'fall_back') + 11,index($record,'"',index($record,'fall_back')+ 12)- index($record,'fall_back') - 11);
 	        }
 	        if (($fb) && ($id)) {	     	   
 					$Array_fb{"$id"}=$fb;
@@ -643,7 +666,7 @@ sub handler {
     		$user_agent=lc($ArrayQuery{amf});
     	  }
 
-    }    
+    }
 
 	if ($user_agent =~ m/blackberry/i) {	 
 		$user_agent=substr($user_agent,index($user_agent,'blackberry'));
@@ -679,17 +702,18 @@ sub handler {
 							$id='generic_web_browser';
 					} else {
 						#this check the correct version of Android
-						
-						if ($version ne 'nc') {
-							my $lengthId=length($version);
-							my $count=0;
-							while($count<$lengthId) {								
-								my $idToCheck=$id."_sub".substr($version,0,length($version)-$count);
-								if ($Array_fb{$idToCheck}) {
-									$id=$idToCheck;
-									$count=$lengthId;
+						if ($version) {
+							if ($version ne 'nc') {
+								my $lengthId=length($version);
+								my $count=0;
+								while($count<$lengthId) {								
+									my $idToCheck=$id."_sub".substr($version,0,length($version)-$count);
+									if ($Array_fb{$idToCheck}) {
+										$id=$idToCheck;
+										$count=$lengthId;
+									}
+									$count++;
 								}
-								$count++;
 							}
 						}
 					}
@@ -713,7 +737,7 @@ sub handler {
 					}
 					$id=$ArrayCapFound{id};								   
 			} else {
-					%ArrayCapFound=FallBack($id);         
+					%ArrayCapFound=FallBack($id);
 					foreach $capability2 (sort keys %ArrayCapFound) {
 						$variabile2="$variabile2$capability2=$ArrayCapFound{$capability2}&";
 						my $upper=uc($capability2);
@@ -729,7 +753,14 @@ sub handler {
 						$f->err_headers_out->set('Set-Cookie' => "amf=$id; path=/;");	
 			}		  			  
 	} 
-    
+        my $amf_device_ismobile = 'true';
+	if (($ArrayCapFound{'device_claims_web_support'}) && ($ArrayCapFound{'device_claims_web_support'})) {
+		if ($ArrayCapFound{'device_claims_web_support'} eq 'true' && $ArrayCapFound{'is_wireless_device'} eq 'false') {
+			$amf_device_ismobile = 'false';		
+		}
+	}
+	$f->pnotes("amf_device_ismobile" => $amf_device_ismobile);
+	$f->subprocess_env("AMF_DEVICE_IS_MOBILE" => $amf_device_ismobile);
 	$f->subprocess_env("AMF_VER" => $VERSION);
 	$f->subprocess_env("AMF_WURFLVER" => $WURFLVersion);
 	$f->subprocess_env("AMF_PATCHFILEVER" => $WURFLPatchVersion);
@@ -751,9 +782,7 @@ Apache2::AMFWURFLFilterMemcached - The module detects the mobile device and pass
 
 =head1 SEE ALSO
 
-For more details: http://wiki.apachemobilefilter.org
-
-Demo page of the filter: http://www.apachemobilefilter.org
+Site: http://www.apachemobilefilter.org
 
 =head1 AUTHOR
 
